OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "The mountpoint name contains invalid characters." : "Името на mountpoint-a съдържа невалидни символи.",
    "Not allowed to create a federated share with the same user server" : "Не е разрешено създаването на федаривно споделяне със същия потребителски сърър",
    "Could not authenticate to remote share, password might be wrong" : "Неуспешно автентициране към отсрещната страна, паролата може да е грешна",
    "Storage not valid" : "Невалидно дисково пространство.",
    "Couldn't add remote share" : "Неуспешно добавяне на отдалечена споделена директория.",
    "Shared with you" : "Споделено с теб",
    "Shared with others" : "Споделено с други",
    "Shared by link" : "Споделено с връзка",
    "Anonymous upload" : "Анонимно качване",
    "Click to select files or use drag & drop to upload" : "Кликнете, за да изберете файлове или използвайте „drag & drop“ за качване",
    "Uploaded files" : "Качени файлове",
    "Uploading..." : "Качване...",
    "Nothing shared with you yet" : "Все още няма нищо споделено с теб",
    "Files and folders others share with you will show up here" : "Файлове и папки, споделени от други с теб, ще се показват тук",
    "Nothing shared yet" : "Още нищо не е споделено",
    "Files and folders you share will show up here" : "Файлове и папки, които ти споделяшм ще се показват тук.",
    "No shared links" : "Няма споделени връзки",
    "Files and folders you share by link will show up here" : "Файлове и директории, които ти споделяш чрез връзки, ще се показват тук",
    "An error occurred while updating share state: {message}" : "Възникна грешка при актуализиране на състоянието на споделянето: {message}",
    "Accept Share" : "Приемете споделянето",
    "Decline Share" : "Отклонете споделянето",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Желаеш ли да добавиш като прикачената папка {name} от {owner}@{remote}?",
    "Remote share" : "Прикачена Папка",
    "Remote share password" : "Парола за прикачена папка",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави прикачена папка",
    "You can upload into this folder" : "Може да качвате в тази папка",
    "No ownCloud installation (7 or higher) found at {remote}" : "Не е открита ownCloud ( 7 или по-висока ) инсталация на {remote}.",
    "Invalid ownCloud url" : "Невалиден ownCloud интернет адрес.",
    "Share" : "Споделяне",
    "No expiration date set" : "Не е зададена дата на изтичане",
    "Declined" : "Отхвърляне",
    "Pending" : "Чакащо",
    "Shared by" : "Споделено от",
    "Sharing" : "Споделяне",
    "A file or folder has been <strong>shared</strong>" : "Файл или папка беше <strong>споделен/а</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл или папка е споделен от  <strong>друг сървър</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Публично споделен файл или папка е  <strong>изтеглен</strong>",
    "You received a new remote share %2$s from %1$s" : "Получихте нова, отдалечена папка за споделяне %2$s от %1$s",
    "You received a new remote share from %s" : "Получихте нова, отдалечена папка за споделяне от %s",
    "%1$s accepted remote share %2$s" : "%1$s прие отделечената папка за споделяне %2$s",
    "%1$s declined remote share %2$s" : "%1$s отхвърли отдалечената папка за споделяне %2$s",
    "%1$s unshared %2$s from you" : "%1$s спря споделянето на %2$s с теб",
    "Public shared folder %1$s was downloaded" : "Публично споделената папка %1$s бе изтеглена",
    "Public shared file %1$s was downloaded" : "Публично споделения файл %1$s бе изтеглен",
    "You shared %1$s with %2$s" : "Вие споделихте %1$s с %2$s.",
    "%2$s shared %1$s with %3$s" : "%2$s сподели %1$s с %3$s",
    "You removed the share of %2$s for %1$s" : "Премахнахте споделената папка %2$s за %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s премахна споделената папка %3$s за %1$s",
    "You unshared %1$s shared by %2$s from self" : "Вие не споделяте %1$s споделеният %2$s със себе си",
    "You shared %1$s with group %2$s" : "Вие споделихте %1$s с групата %2$s.",
    "%2$s shared %1$s with group %3$s" : "%2$s сподели %1$s с група %3$s",
    "You removed the share of group %2$s for %1$s" : "Премахнахте споделената папка на група %2$s за %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s премахна споеделената папка на група %3$s за %1$s",
    "%2$s shared %1$s via link" : "%2$s сподели %1$s с връзка",
    "You shared %1$s via link" : "Вие споделихте %1$s посредством връзка.",
    "You removed the public link for %1$s" : "Премахнахте публичната връзка за %1$s",
    "%2$s removed the public link for %1$s" : "%2$s премахна публичната връзка за %1$s",
    "Your public link for %1$s expired" : "Публичната Ви връзка за %1$s изтече",
    "The public link of %2$s for %1$s expired" : "Публичната връзка на %2$s за %1$s изтече",
    "%2$s shared %1$s with you" : "%2$s сподели %1$s с Вас.",
    "%2$s removed the share for %1$s" : "%2$s премахна споделянето на %1$s",
    "Downloaded via public link" : "Изтеглено през публична връзка",
    "Shared with %2$s" : "Споделено с %2$s",
    "Shared with %3$s by %2$s" : "Споделено с %3$s от %2$s",
    "Removed share for %2$s" : "Премахнато споделяне за %2$s",
    "%2$s removed share for %3$s" : "%2$s премахна споделянето на %3$s",
    "Unshared %1$s from self" : "Вие не споделяте %1$s със себе си",
    "Shared with group %2$s" : "Споделено с група %2$s",
    "Shared with group %3$s by %2$s" : "Споделено с група %3$s от %2$s",
    "Removed share of group %2$s" : "Премахнато споделяне с група %2$s",
    "%2$s removed share of group %3$s" : "%2$s премахна споделяне с група %3$s",
    "Shared via link by %2$s" : "Споделено с връзка от %2$s",
    "Shared via public link" : "Споделено с публична връзка",
    "Removed public link" : "Премахната публична връзка",
    "%2$s removed public link" : "%2$s премахна публична връзка",
    "Public link expired" : "Публичната връзка изтече",
    "Public link of %2$s expired" : "Публичната връзка %2$s изтече",
    "Shared by %2$s" : "Споделено от %2$s",
    "Shares" : "Споделени Папки",
    "File sharing" : "Споделяне на файл",
    "Public link" : "Публичнa връзкa",
    "Couldn't send mail to following recipient(s): %s " : "Не можа да се изпрати поща до следният получател(и): %s",
    "Share API is disabled" : "API-то за споделяне е деактивирано",
    "Wrong share ID, share doesn't exist" : "Грешно ID за споделяне, папката не съществува",
    "Could not delete share" : "Неуспешно изтриване на споделена папка",
    "Please specify a file or folder path" : "Моля, задайте път до папка или файл",
    "Wrong path, file/folder doesn't exist" : "Грешен път, файлът/папката не съществуват",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът на датата трябва да бъде YYYY-MM-DD",
    "Please specify a valid user" : "Моля, задайте валиден потребител",
    "Group sharing is disabled by the administrator" : "Групово споделяне е деактивирано от администраторът",
    "Please specify a valid group" : "Моля, задайте валидна група",
    "The group is blacklisted for sharing" : "Групата е в черния списък за споделяне",
    "Public link sharing is disabled by the administrator" : "Публичните връзи за споделяне са деактивирани от администратора",
    "Public upload disabled by the administrator" : "Публичното качване е деактивирано от администратора",
    "Public upload is only possible for publicly shared folders" : "Публичното качване е единствено възможно от публично споделени папки",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Споделянето на %s е неуспешно, защото бекендът не разрешава споделяне от тип %s",
    "Unknown share type" : "Непознат тип на споделяне",
    "Could not lock path" : "Неуспешно заключване на пътя",
    "Not a directory" : "Не е папка",
    "Could not update share" : "Не можа да се актуализира споделянето",
    "Can't change permissions for public share links" : "Неуспешна промяна на правилата за публично споделяне на връзки",
    "Only recipient can change accepted state" : "Само получателят може да промени състоянието при приемане",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" сподели \"%3$s\" с вас (от името на \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" сподели \"%3$s\" с вас",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" ви покани да прегледате \"%3$s\" (от името на \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" ви покани да прегледате \"%3$s\"",
    "Accept" : "Приемам",
    "Decline" : "Отказвам",
    "Automatically accept new incoming local user shares" : "Автоматично приемане на нови входящи локални споделяния от потребители",
    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "Позволяване да се намери потребител чрез автоматично завършване в диалоговия прозорец за споделяне. Ако това е деактивирано ще трябва да се въведе пълното потребителско име.",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong. Try again." : "Грешна парола. Опитай отново.",
    "Password" : "Парола",
    "No entries found in this folder" : "Няма намерени записи в тази директория",
    "Name" : "Име",
    "State" : "Състояние",
    "Share time" : "Споделено на",
    "Expiration date" : "Дата на изтичане",
    "Sorry, this link doesn’t seem to work anymore." : "Съжаляваме, връзката вече не е активна.",
    "Reasons might be:" : "Причините може да са:",
    "the item was removed" : "съдържанието е премахнато",
    "the link expired" : "връзката е изтекла",
    "sharing is disabled" : "споделянето е изключено",
    "For more info, please ask the person who sent this link." : "За повече информация, моля питай човека, който е изпратил тази връзка.",
    "%s is publicly shared" : "%s е публично споделна",
    "Download" : "Изтегли",
    "Download %s" : "Изтегли %s",
    "Direct link" : "Директна връзка",
    "Nothing to configure." : "Няма нищо за конфигуриране.",
    "Group Sharing Blacklist" : "Черен списък на групи за споделяне",
    "Exclude groups from receiving shares" : "Изключени групи от получаване на споделяния",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Тези групи няма да бъдат достъпни за споделяне. Членовете на групата не са ограничени в инициирането на споделяне и могат да получават споделяния от други групи, на които са членове, както обикновено."
},
"nplurals=2; plural=(n != 1);");
